package com.ruoyi.frequency.pfwithdrawalway.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.pfwithdrawalway.entity.PfWithdrawalWay;
import com.ruoyi.response.ResponseData;

import java.util.List;

/**
 * 后台提现方式Service接口
 * 
 * @author liwenlong
 * @date 2023-07-20
 */
public interface PfWithdrawalWayService extends IService<PfWithdrawalWay>
{
    /**
     * 查询后台提现方式
     * 
     * @param id 后台提现方式主键
     * @return 后台提现方式
     */
    PfWithdrawalWay selectPfWithdrawalWayById(Long id);

    /**
     * 查询后台提现方式列表
     * 
     * @param pfWithdrawalWay 后台提现方式
     * @return 后台提现方式集合
     */
    List<PfWithdrawalWay> selectPfWithdrawalWayList(PfWithdrawalWay pfWithdrawalWay);

    /**
     * 新增后台提现方式
     * 
     * @param pfWithdrawalWay 后台提现方式
     * @return 结果
     */
    int insertPfWithdrawalWay(PfWithdrawalWay pfWithdrawalWay);

    /**
     * 修改后台提现方式
     * 
     * @param pfWithdrawalWay 后台提现方式
     * @return 结果
     */
    int updatePfWithdrawalWay(PfWithdrawalWay pfWithdrawalWay);

    /**
     * 批量删除后台提现方式
     * 
     * @param ids 需要删除的后台提现方式主键集合
     * @return 结果
     */
    int deletePfWithdrawalWayByIds(Long[] ids);

    /**
     * 删除后台提现方式信息
     * 
     * @param id 后台提现方式主键
     * @return 结果
     */
    int deletePfWithdrawalWayById(Long id);

    /**
     * 查询平台提现配置列表
     * @return
     */
    ResponseData pfList();
}
